@@ -1,6 +1,5 @@
 import pytest
 import tensorflow as tf
-import numpy as np
 from tensorflow_similarity.distances import CosineDistance, InnerProductSimilarity
 from tensorflow_similarity.distances import EuclideanDistance
 from tensorflow_similarity.distances import ManhattanDistance
@@ -33,21 +32,30 @@ def test_non_existing_distance():
         distance_canonicalizer('notadistance')
 
 
-def angular_distance_np(feature):
-    """Computes the angular distance matrix in numpy.
-    Args:
-      feature: 2-D numpy array of size [number of data, feature dimension]
-    Returns:
-      angular_distances: 2-D numpy array of size
-        [number of data, number of data].
-    """
+def test_inner_product_similarity():
+    # pairwise
+    a = tf.convert_to_tensor([[1.0, 1.0, 1.0], [1.0, 1.0, 1.0]])
+    d = InnerProductSimilarity()
+    vals = d(a)
+    assert tf.math.reduce_all(tf.shape(vals) == (2, 2))
+    assert tf.round(tf.reduce_sum(vals)) == 12
 
-    # l2-normalize all features
-    normed = feature / np.linalg.norm(feature, ord=2, axis=1, keepdims=True)
-    cosine_similarity = normed @ normed.T
-    inverse_cos_sim = 1 - cosine_similarity
 
-    return inverse_cos_sim
+def test_inner_product_opposite():
+    a = tf.convert_to_tensor([[0.0, 1.0], [1.0, 0.0]])
+    d = InnerProductSimilarity()
+    vals = d(a)
+    assert tf.math.reduce_all(tf.shape(vals) == (2, 2))
+    assert tf.round(tf.reduce_sum(vals)) == 2
+
+
+def test_inner_product_vals():
+    a = tf.nn.l2_normalize([[0.1, 0.3, 0.2], [0.0, 0.1, 0.5]], axis=-1)
+    d = InnerProductSimilarity()
+    vals = d(a)
+    assert tf.math.reduce_all(tf.shape(vals) == (2, 2))
+    assert vals[0][0] == 1
+    assert vals[0][1] == 0.68138516
 
 
 def test_cosine_same():
@@ -55,6 +63,7 @@ def test_cosine_same():
     a = tf.convert_to_tensor([[1.0, 1.0, 1.0], [1.0, 1.0, 1.0]])
     d = CosineDistance()
     vals = d(a)
+    assert tf.math.reduce_all(tf.shape(vals) == (2, 2))
     assert tf.round(tf.reduce_sum(vals)) == 0
 
 
@@ -62,6 +71,7 @@ def test_cosine_opposite():
     a = tf.convert_to_tensor([[0.0, 1.0], [1.0, 0.0]])
     d = CosineDistance()
     vals = d(a)
+    assert tf.math.reduce_all(tf.shape(vals) == (2, 2))
     assert tf.round(tf.reduce_sum(vals)) == 2
 
 
@@ -77,6 +87,7 @@ def test_euclidean():
     a = tf.convert_to_tensor([[0.0, 3.0], [4.0, 0.0]])
     d = EuclideanDistance()
     vals = d(a)
+    assert tf.math.reduce_all(tf.shape(vals) == (2, 2))
     assert tf.round(tf.reduce_sum(vals)) == 10
 
 
@@ -84,6 +95,7 @@ def test_euclidean_same():
     a = tf.convert_to_tensor([[1.0, 1.0], [1.0, 1.0]])
     d = EuclideanDistance()
     vals = d(a)
+    assert tf.math.reduce_all(tf.shape(vals) == (2, 2))
     assert tf.round(tf.reduce_sum(vals)) == 0
 
 
@@ -91,6 +103,7 @@ def test_euclidean_opposite():
     a = tf.convert_to_tensor([[0.0, 1.0], [0.0, -1.0]])
     d = EuclideanDistance()
     vals = d(a)
+    assert tf.math.reduce_all(tf.shape(vals) == (2, 2))
     assert tf.round(tf.reduce_sum(vals)) == 4
 
 
@@ -109,6 +122,7 @@ def test_manhattan():
         [2.0, 1.0, 0.0, 3.0],
         [3.0, 4.0, 3.0, 0.0]
     ])
+    assert tf.math.reduce_all(tf.shape(vals) == (4, 4))
     assert tf.reduce_all(tf.math.equal(vals, expected))
 
 
@@ -116,6 +130,7 @@ def test_manhattan_same():
     a = tf.convert_to_tensor([[1.0, 1.0], [1.0, 1.0]])
     d = ManhattanDistance()
     vals = d(a)
+    assert tf.math.reduce_all(tf.shape(vals) == (2, 2))
     assert tf.round(tf.reduce_sum(vals)) == 0
 
 
@@ -123,11 +138,5 @@ def test_manhattan_opposite():
     a = tf.convert_to_tensor([[0.0, 1.0], [0.0, -1.0]])
     d = ManhattanDistance()
     vals = d(a)
+    assert tf.math.reduce_all(tf.shape(vals) == (2, 2))
     assert tf.round(tf.reduce_sum(vals)) == 4
-
-
-def test_innerprod():
-    a = [[1, 2, 3], [1, 3, 3]]
-    d = InnerProductSimilarity()
-    vals = d(a)
-    assert tf.round(tf.reduce_sum(vals)) == 65
